==> jscommunicator-1.0.21.tgz: package/lib/patientPromoAndroidPush.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var basePush = require('./basePush');
var types = require('./types');
var exceptions = require('./exceptions');
var queueNames = require('./queueNames');

var BasePush = basePush.BasePush;
var PatientPromoAndroidPushObj = types.PatientPromoAndroidPushObj;
var PushValidationException = exceptions.PushValidationException;

var PatientPromoAndroidPush = function (_BasePush) {
    _inherits(PatientPromoAndroidPush, _BasePush);

    function PatientPromoAndroidPush(host, config, appName) {
        _classCallCheck(this, PatientPromoAndroidPush);

        var _this = _possibleConstructorReturn(this, (PatientPromoAndroidPush.__proto__ || Object.getPrototypeOf(PatientPromoAndroidPush)).call(this, host, config, appName));

        _this.comm_app_name = 'fabric-droid';
        _this.pushNotification = new PatientPromoAndroidPushObj();
        _this.pushNotification.service = appName;
        _this.queue_name = queueNames.sendPatientPromoPushQueue;
        return _this;
    }

    _createClass(PatientPromoAndroidPush, [{
        key: 'validateFilters',
        value: function validateFilters(inputDict) {
            this.validatePushRelationKeys(inputDict);
        }
    }, {
        key: 'validatePushType',
        value: function validatePushType(pushType) {
            var allowed_types = [];
            if (allowed_types.indexOf(pushType) == -1) throw new PushValidationException("Invalid push notification type");
        }
    }]);

    return PatientPromoAndroidPush;
}(BasePush);

module.exports = {
    PatientPromoAndroidPush: PatientPromoAndroidPush
};

==> jscommunicator-1.0.26.tgz: package/lib/patientPromoAndroidPush.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var basePush = require('./basePush');
var types = require('./types');
var exceptions = require('./exceptions');
var queueNames = require('./queueNames');

var BasePush = basePush.BasePush;
var PatientPromoAndroidPushObj = types.PatientPromoAndroidPushObj;
var PushValidationException = exceptions.PushValidationException;

var PatientPromoAndroidPush = function (_BasePush) {
    _inherits(PatientPromoAndroidPush, _BasePush);

    function PatientPromoAndroidPush(host, config, appName) {
        _classCallCheck(this, PatientPromoAndroidPush);

        var _this = _possibleConstructorReturn(this, (PatientPromoAndroidPush.__proto__ || Object.getPrototypeOf(PatientPromoAndroidPush)).call(this, host, config, appName));

        _this.comm_app_name = 'fabric-droid';
        _this.pushNotification = new PatientPromoAndroidPushObj();
        _this.pushNotification.service = appName;
        _this.queueName = queueNames.sendPatientPromoPushQueue;
        return _this;
    }

    _createClass(PatientPromoAndroidPush, [{
        key: 'validateFilters',
        value: function validateFilters(inputDict) {
            this.validatePushRelationKeys(inputDict);
        }
    }, {
        key: 'validatePushType',
        value: function validatePushType(pushType) {
            var allowed_types = [];
            if (allowed_types.indexOf(pushType) == -1) throw new PushValidationException("Invalid push notification type");
        }
    }]);

    return PatientPromoAndroidPush;
}(BasePush);

module.exports = {
    PatientPromoAndroidPush: PatientPromoAndroidPush
};
